@@ -1,30 +1,32 @@
 from django.contrib import admin
-
+from config.config import Config
 # 引入用户平台
 from .models import *
-from config.config import Config
 
 config = Config()
 
+
 # Register your models here.
-admin.site.site_title = config.get('app', 'app_name')  # 登录页面的标题
-admin.site.site_header = 'MSA一体化管理系统'  # 登录框的标题
-admin.site.index_title = 'MSA一体化管理后台'  # 首页的标题
 
 
 class BaseInfoAdmin(admin.ModelAdmin):
     # fields = ('user_name', 'full_name', 'platform', 'platform_uid', 'phone', 'email', 'wechat', 'user_info')
-    fields = ('user_name', 'full_name', 'nickname', 'phone', 'email', 'wechat_openid', 'user_info', 'user_group', 'permission', 'register_time')
-    list_display = ('id', 'user_name', 'full_name', 'nickname', 'phone', 'email', 'wechat_openid', 'user_info', 'user_group', 'permission', 'register_time')
+    fields = ('id', 'user_name', 'full_name', 'nickname', 'phone', 'email', 'wechat_openid', 'user_info', 'user_group',
+              'permission', 'register_time')
+    list_display = (
+    'id', 'user_name', 'full_name', 'nickname', 'phone', 'email', 'wechat_openid', 'user_info', 'user_group',
+    'permission', 'register_time')
     search_fields = ('user_name', 'full_name', 'nickname', 'phone', 'user_group__group')
     list_filter = []
+    readonly_fields = ['id']
 
 
 class AuthAdmin(admin.ModelAdmin):
-    fields = ('user', 'password', 'token', 'ticket',)
+    fields = ('id', 'user', 'password', 'salt', 'algorithm', 'token', 'ticket', 'create_time', 'update_time')
     list_display = ('user', 'password', 'token', 'create_time', 'update_time',)
     search_fields = ('user', 'create_time')
     list_filter = ['user']
+    readonly_fields = ['id', 'create_time', 'update_time']
 
     # def platform(self, obj):
     #     return obj.platform
@@ -32,32 +34,37 @@ class AuthAdmin(admin.ModelAdmin):
 
 class DetailInfoAdmin(admin.ModelAdmin):
     fields = (
-        'user', 'real_name', 'sex', 'birth', 'tags', 'signature', 'avatar', 'cover', 'language', 'region_code',
+        'id', 'user', 'real_name', 'sex', 'birth', 'tags', 'signature', 'avatar', 'cover', 'language', 'region_code',
         'more',
         'field_1', 'field_2', 'field_3', 'field_4', 'field_5', 'field_6', 'field_7', 'field_8', 'field_9',
         'field_10', 'field_11', 'field_12', 'field_13', 'field_14', 'field_15'
     )
     list_display = ('user', 'real_name', 'sex', 'birth', 'tags', 'avatar', 'cover', 'language', 'region_code')
+    readonly_fields = ['id']
 
 
-class ExtendFiledAdmin(admin.ModelAdmin):
-    fields = ('field', 'field_index', 'description')
+class ExtendFieldAdmin(admin.ModelAdmin):
+    fields = ('id', 'field', 'field_index', 'description')
     list_display = ('field', 'field_index', 'description')
+    readonly_fields = ['id']
 
 
 class AccessLogAdmin(admin.ModelAdmin):
-    fields = ('user', 'ip', 'create_time', 'client_info', 'more',)
+    fields = ('id', 'user', 'ip', 'create_time', 'client_info', 'more',)
     list_display = ('user', 'ip', 'create_time', 'client_info',)
+    readonly_fields = ['id', 'create_time']
 
 
 class HistoryAdmin(admin.ModelAdmin):
-    fields = ('user', 'field', 'old_value', 'new_value', 'create_time',)
+    fields = ('id', 'user', 'field', 'old_value', 'new_value', 'create_time',)
     list_display = ('user', 'field', 'old_value', 'new_value', 'create_time',)
+    readonly_fields = ['id', 'create_time']
 
 
 class RestrictRegionAdmin(admin.ModelAdmin):
-    fields = ('user', 'region_code',)
+    fields = ('id', 'user', 'region_code',)
     list_display = ('user', 'region_code',)
+    readonly_fields = ['id']
 
 
 class PlatformAdmin(admin.ModelAdmin):
@@ -67,8 +74,9 @@ class PlatformAdmin(admin.ModelAdmin):
 
 
 class PlatformsToUsersAdmin(admin.ModelAdmin):
-    fields = ('platform', 'platform_user_id',)
+    fields = ('id', 'platform', 'platform_user_id',)
     list_display = ('platform', 'platform_user_id',)
+    readonly_fields = ['id']
 
 
 class PermissionAdmin(admin.ModelAdmin):
@@ -77,13 +85,25 @@ class PermissionAdmin(admin.ModelAdmin):
 
 
 class PermissionValueAdmin(admin.ModelAdmin):
-    fields = ('permission', 'value', 'is_system', 'is_ban',)
-    list_display = ('permission', 'value', 'is_system', 'is_ban',)
+    fields = ('id', 'permission', 'module', 'feature', 'permission_value', 'type',
+              'relate_value', 'config', 'is_enable','is_system', 'is_ban', 'ban_view', 'ban_edit', 'ban_add', 'ban_delete',
+              'description')
+    list_display = ('permission', 'permission_value', 'type', 'is_system', 'is_ban',)
+    readonly_fields = ['id']
 
 
 class GroupAdmin(admin.ModelAdmin):
-    fields = ('group', 'parent_group', 'description')
+    fields = ('id', 'group', 'parent_group', 'description')
     list_display = ('id', 'group', 'parent_group', 'description')
+    readonly_fields = ['id']
+
+
+class ContactBookAdmin(admin.ModelAdmin):
+    fields = ('id', 'user_id', 'friend', 'phone', 'phones', 'telephone', 'telephones',
+              'email', 'qq', 'address', 'more', 'remarks')
+    list_display = ('id', 'user_id', 'friend', 'phone', 'phones', 'telephone', 'telephones',
+              'email', 'qq', 'address', 'more', 'remarks')
+    readonly_fields = ['id']
 
 
 admin.site.register(BaseInfo, BaseInfoAdmin)
@@ -97,4 +117,5 @@ admin.site.register(PlatformsToUsers, PlatformsToUsersAdmin)
 admin.site.register(Permission, PermissionAdmin)
 admin.site.register(PermissionValue, PermissionValueAdmin)
 admin.site.register(Group, GroupAdmin)
-admin.site.register(ExtendFiled, ExtendFiledAdmin)
+admin.site.register(ContactBook, ContactBookAdmin)
+admin.site.register(ExtendField, ExtendFieldAdmin)
