@@ -15,11 +15,12 @@ from xj_user.utils.custom_response import util_response
 class WechetLogin(APIView):
     # 微信手机号码登录
     def post(self, request):
-        code = self.request.data.get('code', None)
-        if not code:
+        phone_code = self.request.data.get('phone_code', None)
+        login_code = self.request.data.get('login_code', None)
+        if not phone_code:
             return util_response(err=6558, msg='参数错误')
         app = WechatService()
-        err, data = app.phone_login(code=code)
+        err, data = app.wechat_login(phone_code=phone_code,login_code=login_code)
         if err == 0:
             return util_response(data=data)
         else:
