@@ -5,18 +5,22 @@ from django.urls import re_path
 # from django.urls import include
 # from django.views.generic import TemplateView
 # from django.contrib.auth.decorators import login_required
+from .apis import user_add
 from .apis import user_contact_book
 from .apis import user_detail_info
-from .apis import user_group
-from .apis import user_info
 from .apis import user_edit
+from .apis import user_group
+from .apis import user_group_tree
+from .apis import user_info
 from .apis import user_list
 from .apis import user_login
+from .apis import user_login_short_message
 from .apis import user_login_wechat
 from .apis import user_password
+from .apis import user_permission
 from .apis import user_platform
 from .apis import user_register
-from .apis import user_edit
+# from .apis import user_short_message
 
 # 应用名称
 app_name = 'xj_user'
@@ -31,18 +35,26 @@ urlpatterns = [
     re_path(r'^list/?$', user_list.UserListAPIView.as_view(), ),  # 用户列表
     re_path(r'^info/?$', user_info.UserInfo.as_view(), ),
     re_path(r'^edit/?$', user_edit.UserEdit.as_view(), ),
+    re_path(r'^add/?$', user_add.UserAdd.as_view(), ),  # 管理员添加用户
+    re_path(r'^delete/?$', user_edit.UserEdit.as_view(), ),  # 管理员添加用户
 
     re_path(r'^password/?$', user_password.UserPassword.as_view(), ),
     re_path(r'^contact_book/?$', user_contact_book.UserContactBook.as_view(), ),
 
-    # 详细信息查询/新增/修改
+    # 详细信息查询/新增/修改group_tree
     re_path(r'^list_detail/?$', user_detail_info.UserListDetail.as_view(), ),
     re_path(r'^detail/?$', user_detail_info.UserDetail.as_view(), ),
     # re_path(r'^detail_add/?$', user_detail_info.UserDetailAdd.as_view(), ),  # 用户必须存在才有信息编辑，所以这个接口是多余的
     re_path(r'^detail_edit/?$', user_detail_info.UserDetailEdit.as_view(), ),
+    re_path(r'^group_tree/?$', user_group_tree.UserGroupTree.as_view(), ),
 
     # 分组
     re_path(r'^group/?$', user_group.GroupAPIView.as_view(), ),
     re_path(r'^group_list/?$', user_group.GroupAPIView.list, ),
 
+    # re_path(r'^send_message/?$', user_short_message.UserShortMessage.as_view(), ),
+    re_path(r'^login_short_message/?$', user_login_short_message.ShortMessageLogin.as_view(), ),
+
+    re_path(r'^permission/?$', user_permission.UserPermissions.as_view(), ),
+
 ]
