@@ -8,11 +8,16 @@ from rest_framework import status
 
 
 # 数据返回规则
-def util_response(data='', err=0, http_status=status.HTTP_200_OK, msg='ok'):
+def util_response(data='', err=0, msg='ok', http_status=status.HTTP_200_OK, cookie=None):
     if http_status == status.HTTP_200_OK:
-        return JsonResponse({'err': err, 'msg': msg, 'data': data})
+        return JsonResponse({'err': err, 'msg': msg, 'data': data or {}})
     else:
-        return JsonResponse({'err': http_status, 'msg': msg,}, status=http_status)
+        print("> util_response:", http_status)
+        return JsonResponse({'err': http_status, 'msg': msg, }, status=http_status)
+    if cookie and isinstance(cookie, dict):
+        for k, v in cookie.items():
+            response.set_cookie(k, v)
+    return response
 
 
 # 自定义错误页面时返回【DEBUG为True时生效】
